@@ -1,4 +1,4 @@
-package org.ddahl.bamboo.clustering
+//package org.ddahl.bamboo.clustering
 
 //import org.ddahl.onion.r.jvm.NonconjugateFunctions
 //import org.ddahl.onion.util.RandomData
